from distutils.core import setup

setup (
	name = 'wester-applez',
	username = 'AppleZ',
	version = '1.3.0',
	py_modules = ['wester'],
	author = 'cyd',
	author_email = 'hfpython@headfirstlabs.com',
	url = 'http://www.wzcc.com',
	description = 'A simple printer of nested lists'
)
